==> ring_redis-0.8.0.zip: ring_redis-0.8.0/setup.py <==
import os
import sys

from distutils.util import convert_path
from fnmatch import fnmatchcase
from setuptools import setup, find_packages

def read(fname):
	with open(os.path.join(os.path.dirname(__file__), fname), 'r') as fin:
		r = fin.read()
	return r
	#return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()

# Provided as an attribute, so you can append to these instead
# of replicating them:
standard_exclude = ["*.py", "*.pyc", "*$py.class", "*~", ".*", "*.bak"]
standard_exclude_directories = [
	".*", "CVS", "_darcs", "./build", "./dist", "EGG-INFO", "*.egg-info"
]

# (c) 2005 Ian Bicking and contributors; written for Paste (http://pythonpaste.org)
# Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
# Note: you may want to copy this into your setup.py file verbatim, as
# you can't import this from another package, when you don't know if
# that package is installed yet.
def find_package_data(
	where=".",
	package="",
	exclude=standard_exclude,
	exclude_directories=standard_exclude_directories,
	only_in_packages=True,
	show_ignored=False):
	"""
	Return a dictionary suitable for use in ``package_data``
	in a distutils ``setup.py`` file.

	The dictionary looks like::

		{"package": [files]}

	Where ``files`` is a list of all the files in that package that
	don"t match anything in ``exclude``.

	If ``only_in_packages`` is true, then top-level directories that
	are not packages won"t be included (but directories under packages
	will).

	Directories matching any pattern in ``exclude_directories`` will
	be ignored; by default directories with leading ``.``, ``CVS``,
	and ``_darcs`` will be ignored.

	If ``show_ignored`` is true, then all the files that aren"t
	included in package data are shown on stderr (for debugging
	purposes).

	Note patterns use wildcards, or can be exact paths (including
	leading ``./``), and all searching is case-insensitive.
	"""
	out = {}
	stack = [(convert_path(where), "", package, only_in_packages)]
	while stack:
		where, prefix, package, only_in_packages = stack.pop(0)
		for name in os.listdir(where):
			fn = os.path.join(where, name)
			if os.path.isdir(fn):
				bad_name = False
				for pattern in exclude_directories:
					if (fnmatchcase(name, pattern)
						or fn.lower() == pattern.lower()):
						bad_name = True
						if show_ignored:
							print >> sys.stderr, (
								"Directory %s ignored by pattern %s"
								% (fn, pattern))
						break
				if bad_name:
					continue
				if (os.path.isfile(os.path.join(fn, "__init__.py"))
					and not prefix):
					if not package:
						new_package = name
					else:
						new_package = package + "." + name
					stack.append((fn, "", new_package, False))
				else:
					stack.append((fn, prefix + name + "/", package, only_in_packages))
			elif package or not only_in_packages:
				# is a file
				bad_name = False
				for pattern in exclude:
					if (fnmatchcase(name, pattern)
						or fn.lower() == pattern.lower()):
						bad_name = True
						if show_ignored:
							print >> sys.stderr, (
								"File %s ignored by pattern %s"
								% (fn, pattern))
						break
				if bad_name:
					continue
				out.setdefault(package, []).append(prefix+name)
	return out

##################################################################

PACKAGE = "ring_redis"
NAME = "ring_redis"
DESCRIPTION = "a lightweight, high available & extensible cache solution using redis"
AUTHOR = "luo chen"
AUTHOR_EMAIL = "luochen1990@gmail.com"
URL = "https://github.com/luochen1990/ring_redis"
VERSION = "0.8.0"

setup(
	name=NAME,
	version=VERSION,
	description=DESCRIPTION,
	long_description=read("README.md"),
	author=AUTHOR,
	author_email=AUTHOR_EMAIL,
	license="BSD",
	url=URL,
	packages=find_packages(exclude=["tests.*", "tests"]),
	keywords=["redis", "consistent hash", "high available", "HA", "extensible", "pure python"],
	package_data=find_package_data(
		PACKAGE,
		only_in_packages=False
	),
	classifiers=[
		"Development Status :: 3 - Alpha",
		#"Development Status :: 4 - Beta",
		"Environment :: Web Environment",
		"Intended Audience :: Developers",
		"License :: OSI Approved :: BSD License",
		"Operating System :: OS Independent",
		"Programming Language :: Python",
		"Programming Language :: Python :: 3",
		"Topic :: Software Development :: Libraries :: Python Modules",
	],
	install_requires=[
		'redis>=2.8.0',
	],
	zip_safe=False,
)

==> ring_redis-0.9.0.zip: ring_redis-0.9.0/setup.py <==
import os
import sys

from distutils.util import convert_path
from fnmatch import fnmatchcase
from setuptools import setup, find_packages

def read(fname):
	with open(os.path.join(os.path.dirname(__file__), fname), 'r') as fin:
		r = fin.read()
	return r
	#return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()

# Provided as an attribute, so you can append to these instead
# of replicating them:
standard_exclude = ["*.py", "*.pyc", "*$py.class", "*~", ".*", "*.bak"]
standard_exclude_directories = [
	".*", "CVS", "_darcs", "./build", "./dist", "EGG-INFO", "*.egg-info"
]

# (c) 2005 Ian Bicking and contributors; written for Paste (http://pythonpaste.org)
# Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
# Note: you may want to copy this into your setup.py file verbatim, as
# you can't import this from another package, when you don't know if
# that package is installed yet.
def find_package_data(
	where=".",
	package="",
	exclude=standard_exclude,
	exclude_directories=standard_exclude_directories,
	only_in_packages=True,
	show_ignored=False):
	"""
	Return a dictionary suitable for use in ``package_data``
	in a distutils ``setup.py`` file.

	The dictionary looks like::

		{"package": [files]}

	Where ``files`` is a list of all the files in that package that
	don"t match anything in ``exclude``.

	If ``only_in_packages`` is true, then top-level directories that
	are not packages won"t be included (but directories under packages
	will).

	Directories matching any pattern in ``exclude_directories`` will
	be ignored; by default directories with leading ``.``, ``CVS``,
	and ``_darcs`` will be ignored.

	If ``show_ignored`` is true, then all the files that aren"t
	included in package data are shown on stderr (for debugging
	purposes).

	Note patterns use wildcards, or can be exact paths (including
	leading ``./``), and all searching is case-insensitive.
	"""
	out = {}
	stack = [(convert_path(where), "", package, only_in_packages)]
	while stack:
		where, prefix, package, only_in_packages = stack.pop(0)
		for name in os.listdir(where):
			fn = os.path.join(where, name)
			if os.path.isdir(fn):
				bad_name = False
				for pattern in exclude_directories:
					if (fnmatchcase(name, pattern)
						or fn.lower() == pattern.lower()):
						bad_name = True
						if show_ignored:
							print >> sys.stderr, (
								"Directory %s ignored by pattern %s"
								% (fn, pattern))
						break
				if bad_name:
					continue
				if (os.path.isfile(os.path.join(fn, "__init__.py"))
					and not prefix):
					if not package:
						new_package = name
					else:
						new_package = package + "." + name
					stack.append((fn, "", new_package, False))
				else:
					stack.append((fn, prefix + name + "/", package, only_in_packages))
			elif package or not only_in_packages:
				# is a file
				bad_name = False
				for pattern in exclude:
					if (fnmatchcase(name, pattern)
						or fn.lower() == pattern.lower()):
						bad_name = True
						if show_ignored:
							print >> sys.stderr, (
								"File %s ignored by pattern %s"
								% (fn, pattern))
						break
				if bad_name:
					continue
				out.setdefault(package, []).append(prefix+name)
	return out

##################################################################

PACKAGE = "ring_redis"
NAME = "ring_redis"
DESCRIPTION = "a lightweight, high available & extensible cache solution using redis"
AUTHOR = "luo chen"
AUTHOR_EMAIL = "luochen1990@gmail.com"
URL = "https://github.com/luochen1990/ring_redis"
VERSION = "0.9.0"

setup(
	name=NAME,
	version=VERSION,
	description=DESCRIPTION,
	long_description=read("README.md"),
	author=AUTHOR,
	author_email=AUTHOR_EMAIL,
	license="BSD",
	url=URL,
	packages=find_packages(exclude=["tests.*", "tests"]),
	keywords=["redis", "consistent hash", "high available", "HA", "extensible", "pure python"],
	package_data=find_package_data(
		PACKAGE,
		only_in_packages=False
	),
	classifiers=[
		"Development Status :: 4 - Beta",
		#"Development Status :: 4 - Beta",
		"Environment :: Web Environment",
		"Intended Audience :: Developers",
		"License :: OSI Approved :: BSD License",
		"Operating System :: OS Independent",
		"Programming Language :: Python",
		"Programming Language :: Python :: 3",
		"Topic :: Software Development :: Libraries :: Python Modules",
	],
	install_requires=[
		'redis>=2.8.0',
	],
	zip_safe=False,
)
